about summary refs log tree commit diff
path: root/converter/other/pamtofits.c
diff options
context:
space:
mode:
Diffstat (limited to 'converter/other/pamtofits.c')
-rw-r--r--converter/other/pamtofits.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/converter/other/pamtofits.c b/converter/other/pamtofits.c
index 7a1c70de..85ff7aaa 100644
--- a/converter/other/pamtofits.c
+++ b/converter/other/pamtofits.c
@@ -59,7 +59,7 @@ parseCommandLine(int argc, char ** argv,
    was passed to us as the argv array.  We also trash *argv.
 --------------------------------------------------------------------------*/
     optEntry * option_def;
         /* Instructions to optParseOptions3 on how to parse our options. */
     optStruct3 opt;
 
     unsigned int minSpec;
@@ -79,7 +79,7 @@ parseCommandLine(int argc, char ** argv,
 
     /* Set some defaults the lazy way (using multiple setting of variables) */
 
-    optParseOptions3( &argc, argv, opt, sizeof(opt), 0 );
+    pm_optParseOptions3( &argc, argv, opt, sizeof(opt), 0 );
     /* Uses and sets argc, argv, and some of *cmdlineP and others. */
 
     if (!minSpec)
@@ -59,7 +59,7 @@ parseCommandLine(int argc, char ** argv,
 --------------------------------------------------------------------------*/
     optEntry * option_def;
-        /* Instructions to optParseOptions3 on how to parse our options. */
+        /* Instructions to pm_optParseOptions3 on how to parse our options. */
     optStruct3 opt;
 